"use strict";
/*
 * @Author: Lisc
 * @Date: 2022-04-09 14:46:05
 * @Description: CancelToken 类
 */
Object.defineProperty(exports, "__esModule", { value: true });
var Cancel_1 = require("./Cancel");
var CancelToken = /** @class */ (function () {
    // CancelToken 的构造函数参数支持传入一个 executor 函数，executor函数的参数也是一个函数（取消函数）
    function CancelToken(executor) {
        var _this = this;
        var resolveFn;
        this.promise = new Promise(function (resolve) {
            resolveFn = resolve;
        });
        // 外部调用cancel方法时的执行逻辑
        // 调用外部传入的executor函数，并为executor函数传入函数作为参数（函数即取消函数的逻辑）
        executor(function (message) {
            // 防止多次调用cancel方法
            if (_this.reason) {
                return;
            }
            _this.reason = new Cancel_1.default(message);
            resolveFn(_this.reason);
        });
    }
    CancelToken.prototype.throwIfRequested = function () {
        if (this.reason) {
            throw this.reason;
        }
    };
    /**
     * @description: CancelToken工厂方法
     * @param {*}
     * @return {*}
     */
    CancelToken.source = function () {
        var cancel;
        // 此处的c即为构造函数中执行executor时传入的函数参数
        // 从而完成了将类内的函数传递到类外调用的目的
        var token = new CancelToken(function (c) {
            cancel = c;
        });
        return {
            cancel: cancel,
            token: token
        };
    };
    return CancelToken;
}());
exports.default = CancelToken;
//# sourceMappingURL=CancelToken.js.map