"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var InterceptorManager = /** @class */ (function () {
    function InterceptorManager() {
        this.interceptors = [];
    }
    /**
     * @description: 添加拦截器
     * @param {ResolvedFn} resolve
     * @param {RejectedFn} reject
     * @return {*}
     */
    InterceptorManager.prototype.use = function (resolve, reject) {
        this.interceptors.push({
            resolve: resolve,
            reject: reject
        });
        return this.interceptors.length - 1;
    };
    /**
     * @description: 删除拦截器
     * 注意这里不能直接修改原数组,因为id是数组下标,删除元素数组元素个数改变拦截器id会变化
     * @param {number} id
     * @return {*}
     */
    InterceptorManager.prototype.eject = function (id) {
        if (this.interceptors[id]) {
            this.interceptors[id] = null;
        }
    };
    /**
     * @description: 遍历拦截器,对每个拦截器执行回调函数
     * @param {function} fn
     * @return {*}
     */
    InterceptorManager.prototype.forEach = function (fn) {
        this.interceptors.forEach(function (interceptor) {
            if (interceptor) {
                fn(interceptor);
            }
        });
    };
    return InterceptorManager;
}());
exports.default = InterceptorManager;
//# sourceMappingURL=interceptorManager.js.map