"use strict";
/*
 * @Author: Lisc
 * @Date: 2022-04-06 18:37:46
 * @Description: 默认配置和用户配置合并
 */
Object.defineProperty(exports, "__esModule", { value: true });
var helpers_1 = require("../utils/helpers");
var strategiesMap = Object.create(null);
/**
 * @description: 配置的默认合并策略,用户没有配置的字段,使用默认配置
 * @param {any} defaultVal
 * @param {any} userVal
 * @return {*}
 */
function defaultStrategy(defaultVal, userVal) {
    return typeof userVal === 'undefined' ? defaultVal : userVal;
}
/**
 * @description: 特殊字段配置合并策略,只使用用户的配置
 * @param {any} defaultVal
 * @param {any} userVal
 * @return {*}
 */
function fromUserStrategy(defaultVal, userVal) {
    if (typeof userVal !== 'undefined') {
        return userVal;
    }
}
/**
 * @description:
 * @param {any} defaultVal
 * @param {any} userVal
 * @return {*}
 */
function deepMergeStrategy(defaultVal, userVal) {
    if ((0, helpers_1.isPlainObject)(userVal)) {
        // 用户设置的值为对象,和默认配置对象合并
        return (0, helpers_1.deepCopy)(defaultVal, userVal);
    }
    // 用户没有设置合法值,使用默认配置（auth和headers不可能设置值类型的数据）
    else {
        return (0, helpers_1.deepCopy)(defaultVal);
    }
}
var fromUserStrategyKeys = ['url', 'params', 'data'];
fromUserStrategyKeys.forEach(function (key) {
    strategiesMap[key] = fromUserStrategy;
});
var deepMergeStrategyKeys = ['headers', 'auth'];
deepMergeStrategyKeys.forEach(function (key) {
    strategiesMap[key] = deepMergeStrategy;
});
function mergeConfig(defaultConfig, userConfig) {
    if (!userConfig) {
        userConfig = {};
    }
    var config = Object.create(null);
    for (var key in userConfig) {
        merge(key);
    }
    for (var key in defaultConfig) {
        if (!userConfig[key]) {
            merge(key);
        }
    }
    function merge(key) {
        // 不同的key对应不同的合并策略函数
        var strategy = strategiesMap[key] || defaultStrategy;
        // 使用合并策略函数进行合并
        config[key] = strategy(defaultConfig[key], userConfig[key]);
    }
    return config;
}
exports.default = mergeConfig;
//# sourceMappingURL=mergeConfig.js.map