"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * @Author: Lisc
 * @Date: 2022-03-30 16:36:33
 * @Description: 发送xhr请求
 */
var error_1 = require("../utils/error");
var headers_1 = require("../utils/headers");
var url_1 = require("../utils/url");
var helpers_1 = require("../utils/helpers");
var cookie_1 = require("../utils/cookie");
function xhr(config) {
    return new Promise(function (resolve, reject) {
        var url = config.url, responseType = config.responseType, timeout = config.timeout, cancelToken = config.cancelToken, withCredentials = config.withCredentials, xsrfCookieName = config.xsrfCookieName, xsrfHeaderName = config.xsrfHeaderName, onDownloadProgress = config.onDownloadProgress, onUploadProgress = config.onUploadProgress, auth = config.auth, validateStatus = config.validateStatus, _a = config.method, method = _a === void 0 ? 'get' : _a, _b = config.headers, headers = _b === void 0 ? {} : _b, _c = config.data, data = _c === void 0 ? null : _c;
        var xhr = new XMLHttpRequest();
        // xhr.open(method.toUpperCase(), url!, true)
        xhr.open(method, url, true);
        configXhr();
        addEvents();
        xhr.send(data);
        /**
         * @description: 处理xhr的headers
         * @param {*}
         * @return {*}
         */
        function processHeaders() {
            if ((0, helpers_1.isFormData)(data)) {
                // defaults中将含有data请求的Content-Type全部设置为了application/x-www-form-urlencoded
                // 如果请求数据类型为FormData，需要删除我们默认设置的默认值，让浏览器根据请求数据自动设置为form-data，
                // 即multipart/form-data; boundary=----WebKitFormBoundaryfMam9AjKqWXMBjBF
                delete headers['Content-Type'];
            }
            // XSRF 防御
            if ((withCredentials || (0, url_1.isURLSameOrigin)(url)) && xsrfCookieName) {
                var xsrfToken = cookie_1.default.getCookie(xsrfCookieName);
                if (xsrfToken && xsrfHeaderName) {
                    headers[xsrfHeaderName] = xsrfToken;
                }
            }
            if (auth) {
                headers['Authorization'] = "Basic ".concat(btoa("".concat(auth.username, ":").concat(auth.password)));
            }
            // 给xhr设置请求头
            Object.keys(headers).forEach(function (headerName) {
                if (headerName.toLowerCase() === 'content-type' && data === null) {
                    delete headers[headerName];
                    return;
                }
                xhr.setRequestHeader(headerName, headers[headerName]);
            });
        }
        /**
         * @description: 处理xhr的cancelToken配置
         * @param {*}
         * @return {*}
         */
        function processCancel() {
            if (cancelToken) {
                cancelToken.promise.then(function (reason) {
                    xhr.abort();
                    reject(reason);
                });
            }
        }
        /**
         * @description: 配置xhr，设置xhr的各个属性
         * @param {*}
         * @return {*}
         */
        function configXhr() {
            if (responseType) {
                xhr.responseType = responseType;
            }
            if (timeout) {
                xhr.timeout = timeout;
            }
            if (withCredentials) {
                xhr.withCredentials = withCredentials;
            }
            processHeaders();
            processCancel();
        }
        /**
         * @description: 为xhr设置监听事件
         * @param {*}
         * @return {*}
         */
        function addEvents() {
            if (onDownloadProgress) {
                xhr.onprogress = onDownloadProgress;
            }
            if (onUploadProgress) {
                xhr.upload.onprogress = onUploadProgress;
            }
            xhr.onreadystatechange = function () {
                if (xhr.status === 0) {
                    return;
                }
                if (xhr.readyState !== 4) {
                    return;
                }
                // 成功获取响应
                var responseHeaders = (0, headers_1.parseHeaders)(xhr.getAllResponseHeaders());
                var responseData = responseType && responseType !== 'text' ? xhr.response : xhr.responseText;
                var response = {
                    data: responseData,
                    status: xhr.status,
                    statusText: xhr.statusText,
                    headers: responseHeaders,
                    config: config,
                    request: xhr,
                };
                handleResponseStatus(response);
            };
            // 网络异常错误处理
            xhr.addEventListener('error', function () {
                reject((0, error_1.createError)('Network Error', config, null, xhr));
            });
            // 超时异常处理
            xhr.addEventListener('timeout', function () {
                reject((0, error_1.createError)("Timeout of ".concat(timeout, " ms exceeded"), config, 'ECONNABORTED', xhr));
            });
        }
        /**
         * @description: 根据Http状态码处理响应数据
         * @param {AxiosResponse} res
         * @return {*}
         */
        function handleResponseStatus(resp) {
            if (!validateStatus || validateStatus(resp.status)) {
                resolve(resp);
            }
            else {
                reject((0, error_1.createError)("Request failed with status code ".concat(resp.status), config, null, xhr, resp));
            }
        }
    });
}
exports.default = xhr;
//# sourceMappingURL=xhr.js.map