"use strict";
/*
 * @Author: Lisc
 * @Date: 2022-04-06 14:16:28
 * @Description: Axios配置化的实现
 */
Object.defineProperty(exports, "__esModule", { value: true });
var data_1 = require("./utils/data");
var headers_1 = require("./utils/headers");
//请求的默认配置
var defaults = {
    method: 'get',
    timeout: 0,
    xsrfCookieName: 'XSRF-TOKEN',
    xsrfHeaderName: 'X-XSRF-TOKEN',
    headers: {
        common: {
            Accept: 'application/json,text/plain,*/*',
        },
    },
    transformRequest: [
        function (data, headers) {
            // 设置请求头
            (0, headers_1.setHeaders)(headers, data);
            // 转换为Json字符串
            return (0, data_1.transformRequest)(data);
        },
    ],
    transformResponse: [
        function (data) {
            return (0, data_1.transformResponse)(data);
        },
    ],
    validateStatus: function (status) {
        return status >= 200 && status < 300; //|| status === 304
    },
};
var methodsWithData = ['post', 'put', 'patch'];
var methodsWithoutData = ['get', 'delete', 'head', 'options'];
methodsWithData.forEach(function (method) {
    defaults.headers[method] = {
        'Content-Type': 'application/x-www-form-urlencoded',
    };
});
methodsWithoutData.forEach(function (method) {
    defaults.headers[method] = {};
});
exports.default = defaults;
//# sourceMappingURL=defaults.js.map