"use strict";
/*
 * @Author: Lisc
 * @Date: 2022-03-31 10:39:00
 * @Description: 处理请求头和响应头
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.flattenHeaders = exports.parseHeaders = exports.setHeaders = void 0;
var helpers_1 = require("./helpers");
/**
 * @description: 将用户传入的请求头中的key转换成标准格式
 * 例如 content-type 会被转换成 Content-Type
 * @param {any} headers
 * @param {string} normalizedHeaderName
 * @return {*}
 */
function normalizeHeaderName(headers, normalizedHeaderName) {
    if (!headers) {
        return;
    }
    Object.keys(headers).forEach(function (headerName) {
        if (headerName.toUpperCase() === normalizedHeaderName.toUpperCase() &&
            headerName !== normalizedHeaderName) {
            headers[normalizedHeaderName] = headers[headerName];
            delete headers[headerName];
        }
    });
}
/**
 * @description: xhr 中的data数据不接受对象形式，需要转为Json字符串
 * 而Json字符串会被当做普通文本处理，xhr默认设置的请求头为Content-Type为text/plain，
 * 这里需要将其修改成application/json
 * @param {any} headers
 * @param {any} data
 * @return {*}
 */
function setHeaders(headers, data) {
    var contentTypeStr = 'Content-Type';
    var jsonContentType = 'application/json';
    normalizeHeaderName(headers, contentTypeStr);
    if ((0, helpers_1.isPlainObject)(data)) {
        if (headers && !headers[contentTypeStr]) {
            headers[contentTypeStr] = jsonContentType;
        }
    }
    return headers;
}
exports.setHeaders = setHeaders;
/**
 * @description: 将字符串类型的响应头转成对象形式
 * @param {string} headers
 * @return {*}
 */
function parseHeaders(headers) {
    var parsedHeaders = Object.create(null);
    if (!headers) {
        return parsedHeaders;
    }
    headers.split('\r\n').forEach(function (line) {
        var _a = line.split(':'), key = _a[0], valuesArr = _a.slice(1);
        if (!key) {
            return;
        }
        key = key.trim().toLocaleLowerCase();
        var value = valuesArr.join(':').trim();
        parsedHeaders[key] = value;
    });
    return parsedHeaders;
}
exports.parseHeaders = parseHeaders;
function flattenHeaders(headers, method) {
    if (!headers) {
        return headers;
    }
    // 顺序不可颠倒,后边的优先级高
    var methodMergedHeaders = (0, helpers_1.deepCopy)(headers.common, headers[method]);
    var keysToDelete = [
        'common',
        'get',
        'delete',
        'head',
        'options',
        'post',
        'put',
        'patch',
    ];
    keysToDelete.forEach(function (key) {
        delete headers[key];
    });
    return (0, helpers_1.deepCopy)(methodMergedHeaders, headers);
}
exports.flattenHeaders = flattenHeaders;
//# sourceMappingURL=headers.js.map