"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isURLSearchParams = exports.deepCopy = exports.extend = exports.isFormData = exports.isDate = exports.isPlainObject = void 0;
/*
 * @Author: Lisc
 * @Date: 2022-03-30 21:09:13
 * @Description: 工具类
 */
var Tostring = Object.prototype.toString;
/**
 * @description: 判断一个对象是不是普通对象（是不是通过 "{}" 或者 "new Object" 创建的）
 * @param {any} o
 * @return {*}
 */
function isPlainObject(o) {
    return Tostring.call(o) === '[object Object]';
}
exports.isPlainObject = isPlainObject;
/**
 * @description: 判断一个类型是否为日期类型
 * @param {any} d
 * @return {*}
 */
function isDate(d) {
    return Tostring.call(d) === '[object Date]';
}
exports.isDate = isDate;
function isFormData(val) {
    return typeof val !== 'undefined' && val instanceof FormData;
}
exports.isFormData = isFormData;
function isURLSearchParams(val) {
    return typeof val !== 'undefined' && val instanceof URLSearchParams;
}
exports.isURLSearchParams = isURLSearchParams;
/**
 * @description: 将from对象的所有成员复制到to对象
 * @param {T} to
 * @param {U} from
 * @return {*}
 */
function extend(to, from) {
    for (var key in from) {
        ;
        to[key] = from[key];
    }
    return to;
}
exports.extend = extend;
/**
 * @description: 深拷贝,支持将多个对象的属性拷贝到一个对象中
 * @param {array} objs
 * @return {*}
 */
function deepCopy() {
    var objs = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        objs[_i] = arguments[_i];
    }
    var result = Object.create(null);
    objs.forEach(function (obj) {
        if (obj) {
            Object.keys(obj).forEach(function (key) {
                var val = obj[key];
                if (isPlainObject(val)) {
                    if (isPlainObject(result[key])) {
                        result[key] = deepCopy(result[key], val);
                    }
                    else {
                        result[key] = deepCopy(val);
                    }
                }
                else {
                    result[key] = val;
                }
            });
        }
    });
    return result;
}
exports.deepCopy = deepCopy;
//# sourceMappingURL=helpers.js.map