"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.combineURL = exports.isAbsoluteURL = exports.isURLSameOrigin = exports.getUrlWithParams = void 0;
/*
 * @Author: Lisc
 * @Date: 2022-03-30 20:59:08
 * @Description: 处理请求url路径
 */
var helpers_1 = require("./helpers");
var helpers_2 = require("./helpers");
var helpers_3 = require("./helpers");
/**
 * @description: 用于将一个对象通过 URL 进行传输
 * encodeURIComponent方法将特殊字符比如空格进行编码，
 * 不会对 ASCII 字母和数字进行编码，也不会对这些 ASCII 标点符号进行编码
 * @param {string} preVal
 * @return {string}
 */
function encode(preVal) {
    return encodeURIComponent(preVal)
        .replace(/%40/g, '@')
        .replace(/%3A/gi, ':')
        .replace(/%24/g, '$')
        .replace(/%2C/gi, ',')
        .replace(/%20/g, '+')
        .replace(/%5B/gi, '[')
        .replace(/%5D/gi, ']');
}
/**
 * @description: 拼接得到get请求的url
 * @param {string} url
 * @param {any} params
 * @return {*}
 */
function getUrlWithParams(url, params, paramsSerializer) {
    if (!params) {
        return url;
    }
    var serializedParams;
    // 如果用户自定义了参数序列化方式，使用用户自定义的
    if (paramsSerializer) {
        serializedParams = paramsSerializer(params);
    }
    else if ((0, helpers_3.isURLSearchParams)(params)) {
        // 用户传入的params是URLSearchParams类型，直接转为字符串
        serializedParams = params.toString();
    }
    else {
        // 根据用户配置的params对象，生成序列化后的参数字符串
        var parafragments_1 = [];
        // params实际上是一个对象
        Object.keys(params).forEach(function (key) {
            var val = params[key];
            // 参数值传了一个空值
            if (!val) {
                return;
            }
            // 将每个参数值转成数组方便进行统一处理
            var valArr = [];
            if (Array.isArray(val)) {
                valArr = val;
                key += '[]';
            }
            else {
                valArr = [val];
            }
            valArr.forEach(function (val) {
                if ((0, helpers_2.isDate)(val)) {
                    val = val.toISOString();
                }
                else if ((0, helpers_1.isPlainObject)(val)) {
                    val = JSON.stringify(val);
                }
                // 只有参数值为数组时会push多次
                parafragments_1.push("".concat(encode(key), "=").concat(encode(val)));
            });
        });
        serializedParams = parafragments_1.join('&');
    }
    // 去除url的锚点
    var index = url.indexOf('#');
    if (index !== -1) {
        url = url.slice(0, index);
    }
    // 将url和序列化后的参数字符串拼接
    if (serializedParams.length) {
        url = url + (url.indexOf('?') === -1 ? '?' : '&') + serializedParams;
    }
    return url;
}
exports.getUrlWithParams = getUrlWithParams;
function isURLSameOrigin(url) {
    var parsedOrigin = resolveURL(url);
    return (
    // host为主机和端口，hostname只有主机
    parsedOrigin.protocol === window.location.protocol && parsedOrigin.host === window.location.host);
}
exports.isURLSameOrigin = isURLSameOrigin;
function isAbsoluteURL(url) {
    return /^([a-z][a-z\d\+\-\.]*:)?\/\//i.test(url);
}
exports.isAbsoluteURL = isAbsoluteURL;
function combineURL(baseURL, relativeURL) {
    // 自动删除baseURL后边和relativeURL前边的一个或多个/
    return relativeURL ? baseURL.replace(/\/+$/, '') + '/' + relativeURL.replace(/^\/+/, '') : baseURL;
}
exports.combineURL = combineURL;
var urlParsingNode = document.createElement('a');
function resolveURL(url) {
    urlParsingNode.setAttribute('href', url);
    var protocol = urlParsingNode.protocol, host = urlParsingNode.host;
    return {
        protocol: protocol,
        host: host,
    };
}
//# sourceMappingURL=url.js.map