import { AxiosDefaultRequestConfig, AxiosPromise, AxiosRequestConfig, AxiosResponse, Method } from '../types';
import InterceptorManager from './interceptorManager';
interface Interceptors {
    request: InterceptorManager<AxiosRequestConfig>;
    response: InterceptorManager<AxiosResponse>;
}
export default class Axios {
    defaults: AxiosDefaultRequestConfig;
    interceptors: Interceptors;
    constructor(initConfig: AxiosDefaultRequestConfig);
    /**
     * @description: 直接以函数形式(两种方式)调用axios 和 调用axios的别名(request,get,post等)时,底层的实现方法
     * @param {any} urlOrConfig
     * @param {AxiosRequestConfig} config
     * @return {*}
     */
    request(urlOrConfig: any, config?: any): AxiosPromise;
    get(url: string, config?: AxiosRequestConfig): AxiosPromise;
    delete(url: string, config?: AxiosRequestConfig): AxiosPromise;
    head(url: string, config?: AxiosRequestConfig): AxiosPromise;
    options(url: string, config?: AxiosRequestConfig): AxiosPromise;
    post(url: string, data?: any, config?: AxiosRequestConfig): AxiosPromise;
    put(url: string, data?: any, config?: AxiosRequestConfig): AxiosPromise;
    patch(url: string, data?: any, config?: AxiosRequestConfig): AxiosPromise;
    getUri(config?: AxiosRequestConfig): string;
    /**
     * @description: 支持get、delete、head和options方法
     * @param {Method} method
     * @param {string} url
     * @param {AxiosRequestConfig} config
     * @return {*}
     */
    _requestWithoutData(method: Method, url: string, config?: AxiosRequestConfig): AxiosPromise;
    /**
     * @description: 支持post、put、patch方法
     * @param {*}
     * @return {*}
     */
    _requestWithData(method: Method, url: string, data?: any, config?: AxiosRequestConfig): AxiosPromise;
}
export {};
